KernelTest
==========

.. currentmodule:: QuadratiK.kernel_test

.. autoclass:: KernelTest

.. rubric:: Methods

.. autosummary::
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
        KernelTest.stats
    
    
    
        KernelTest.summary
    
    
    
        KernelTest.test
    
    

----





.. automethod:: KernelTest.stats



.. automethod:: KernelTest.summary



.. automethod:: KernelTest.test



.. raw:: html

     <div style='clear:both'></div>